Maintainers
===========

Mini-AMF is lightly maintained by `Zack Weinberg
<https://www.owlfolio.org/>`_.  To report bugs in Mini-AMF, please
use `Github issues <https://github.com/zackw/mini-amf/issues>`_.

Mini-AMF is **not supported** by anyone.  We do not have the
manpower to help you *use* it, nor to help you debug your program that
uses it.


Former PyAMF maintainers
------------------------

The people originally responsible for writing PyAMF, and maintaining
it through its 0.8 release:

- Nick Joyce
- Thijs Triemstra
- Jacob Feisley
- Arnar Birgisson
- Michael van Tellingen
- Gerard Escalante
- Dave Thompson


Contributors
------------

This section lists other people who have contributed in some way to
Mini-AMF or PyAMF. It is incomplete; if you feel that you or anyone
else should be on this list, please let us know (by filing a Github
issue), and we'll be glad to correct the problem.  Please also let us
know if you would prefer not to appear on this list, or would prefer
to be known by a different name.

- Alex Moiseenko
- Antti Kaihola
- Bob Ippolito
- Corey Farwell
- Doug Bell
- Evert Pot
- George Griffin
- Joachim Bauch
- Joey Smith
- Mattias Ahlbäck
- Nick Joyce
- simonzack
- Ruslan Makhmatkhanov
- wasw100

Thanks also to everyone who keeps sending feedback, helping us improve
Mini-AMF.
